@@ -4,6 +4,13 @@ try:
 except ImportError:
     from Products.CMFCore.CMFCorePermissions import setDefaultRoles
 
+try:
+    # Plone 4 and higher 
+    import plone.app.upgrade 
+    PLONE_VERSION = 4 
+except ImportError: 
+    PLONE_VERSION = 3
+
 PROJECTNAME = 'ATGoogleVideo'
 DEFAULT_ADD_CONTENT_PERMISSION = "Add Google Video"
 
